# GCPScanner

Check how many of your GCP buckets are publicly accessible

## Google Cloud services Authentication

### Option 1

$ gcloud auth application-default login

### Option 2

$ export GOOGLE_APPLICATION_CREDENTIALS="/path/to/keyfile.json"
